@@ -1,5 +1,25 @@
 import json
 
+from webexteamssdk.models.cards import AdaptiveCard
+
+
+def response_from_adaptive_card(adaptive_card: AdaptiveCard):
+    """
+    Convenience method for generating a Response from an AdaptiveCard.
+
+    @param adaptive_card: AdaptiveCard object
+    @return: Response object
+    """
+
+    response = Response()
+    response.text = "This bot requires a client which can render cards."
+    response.attachments = {
+        "contentType": "application/vnd.microsoft.card.adaptive",
+        "content": adaptive_card.to_dict()
+    }
+
+    return response
+
 
 class Response(object):
     def __init__(self, attributes=None):
@@ -12,6 +32,7 @@ class Response(object):
             self.attributes["markdown"] = None
             self.attributes["html"] = None
             self.attributes["files"] = list()
+            self.attributes["attachments"] = list()
 
     @property
     def text(self):
@@ -29,6 +50,14 @@ class Response(object):
     def files(self, val):
         self.attributes["files"].append(val)
 
+    @property
+    def attachments(self):
+        return self.attributes["attachments"]
+
+    @attachments.setter
+    def attachments(self, val):
+        self.attributes["attachments"].append(val)
+
     @property
     def roomId(self):
         return self.attributes["roomId"]
